# rcs - The Rich Communication Services API for Developers

`rcs` is the Pinnacle Python library that provides an API to interact with Rich Communication Services (RCS). This library allows developers to send and receive RCS and SMS messages.

## Documentation
See the [Python API docs](https://docs.trypinnacle.app/documentation/python/quick-start) for detailed information on how to use the library.

See the [API Reference](https://docs.trypinnacle.app/api-reference/endpoint/introduction) for a complete list of available methods and classes.

## Installation
```bash
pip install rcs
```
## Requirements
- Python 3.8 or higher